SWDEV-305992 - Improve texture tests (#2646)

Enable more texture supports for hip-rocclr.
Skip texture tests on device that doesn't support images.
SWDEV-322257 - Fix issues of image tests skipped on
NVidia devices.

Change-Id: Ia99d06b1e97fc945f1b740e47710f4dcd70f38ca


[ROCm/hip commit: 643f8dbd36]
This commit is contained in:
ROCm CI Service Account
2022-05-09 21:16:20 +05:30
committed by GitHub
parent 614529f83b
commit 4a74649360
25 changed files with 132 additions and 68 deletions
@@ -23,10 +23,12 @@ THE SOFTWARE.
template <typename T>
__global__ void tex1dKernelFetch(T *val, hipTextureObject_t obj, int N) {
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
int k = blockIdx.x * blockDim.x + threadIdx.x;
if (k < N) {
val[k] = tex1Dfetch<T>(obj, k);
}
#endif
}
template <typename T>
@@ -203,6 +205,8 @@ bool runTest(const char *description) {
}
TEST_CASE("Unit_hipTextureFetch_vector") {
checkImageSupport();
// test for char
runTest<char1>("char1");
runTest<char2>("char2");